# ldc-tint
Plugins for the [llm-dataset-converter](https://github.com/waikato-datamining/llm-dataset-converter) 
library specific to [Tikanga in Technology project (TinT)](https://www.waikato.ac.nz/rangahau/koi-te-mata-punenga-innovation/TinT/ra3-indigenous-data-in-artificial-intelligence).


## Installation

```bash
pip install git+https://github.com/waikato-llm/llm-dataset-converter.git
pip install git+https://github.com/waikato-llm/ldc-tint.git
```

## Plugins

See [here](plugins/README.md) for an overview of all plugins.
